@@ -2,11 +2,12 @@
 # noqa: F401
 from .main import CrudRepository  # noqa: F401
 from .main import DynamoCrudRepository  # noqa: F401
-from .main import DynamoDBGlobalParameters  # noqa: F401
+from .main import DynamoDBGlobalConfiguration  # noqa: F401
+from .main import MultiTableDynamoCrudRepository  # noqa: F401
 from .main import Repository  # noqa: F401
-from .main import SimulatedDynamoDBResource  # noqa: F401
-from .main import SimulatedTable  # noqa: F401
+from .main import SingleTableDynamoCrudRepository  # noqa: F401
+from .main import ConstantString  # noqa: F401
 from .main import dynamo_entity  # noqa: F401; noqa: F401
 
-__version__ = "0.1.15"
+__version__ = "0.1.21"
 __author__ = """DRUID DEVAX"""
